@@ -1,5 +1,5 @@
 package Dist::Zilla::PluginBundle::Author::OALDERS;
-$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000007';
+$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000008';
 use Moose;
 use namespace::autoclean;
 
@@ -76,11 +76,13 @@ has stopwords_file => (
 sub configure {
     my $self = shift;
 
-    my $readme     = 'README.md';
-    my @from_build = qw(INSTALL META.json);
-    my @copy       = ( 'cpanfile', 'LICENSE', 'Makefile.PL', $readme );
+    my $readme = 'README.md';
+    my @copy   = (
+        'cpanfile', 'Install', 'LICENSE', 'Makefile.PL', 'META.json',
+        $readme
+    );
 
-    my @allow_dirty = ( 'dist.ini', 'Changes', @copy, @from_build );
+    my @allow_dirty = ( 'dist.ini', 'Changes', @copy );
 
     # Must come before Git::Commit
     $self->add_plugins('NextRelease');
@@ -179,7 +181,7 @@ Dist::Zilla::PluginBundle::Author::OALDERS - A plugin bundle for distributions b
 
 =head1 VERSION
 
-version 0.000007
+version 0.000008
 
 =head2 configure
 
